@@ -198,6 +198,7 @@ void ProcessControl::start()
   if ( !mProcess.waitForStarted( ) ) {
     qDebug( "ProcessControl: Unable to start application '%s' (%s)",
             qPrintable( mApplication ), qPrintable( mProcess.errorString() ) );
+    emit unableToStart();
     return;
   }
 
@@ -224,4 +225,9 @@ void ProcessControl::resetCrashCount()
   mCrashCount = 0;
 }
 
+bool ProcessControl::isRunning() const
+{
+  return mProcess.state() != QProcess::NotRunning;
+}
+
 #include "processcontrol.moc"
