@@ -22,10 +22,13 @@
 #define AKONADISERVER_H
 
 #include <QtCore/QPointer>
+#include <QtCore/QVector>
 
+#ifdef Q_OS_WINCE
+#include <QtNetwork/QTcpServer>
+#else
 #include <QtNetwork/QLocalServer>
-
-#include "akonadiprivate_export.h"
+#endif
 
 class QProcess;
 class IntervalCheck;
@@ -37,7 +40,11 @@ class CacheCleaner;
 class SearchManager;
 class ItemRetrievalThread;
 
-class AKONADIPRIVATE_EXPORT AkonadiServer: public QLocalServer
+#ifdef Q_OS_WINCE
+class AkonadiServer: public QTcpServer
+#else
+class AkonadiServer: public QLocalServer
+#endif
 {
     Q_OBJECT
 
@@ -59,7 +66,11 @@ class AKONADIPRIVATE_EXPORT AkonadiServer: public QLocalServer
 
   protected:
     /** reimpl */
+#ifdef Q_OS_WINCE
+    void incomingConnection( int socketDescriptor );
+#else
     void incomingConnection( quintptr socketDescriptor );
+#endif
 
   private:
     void startDatabaseProcess();
@@ -73,7 +84,7 @@ class AKONADIPRIVATE_EXPORT AkonadiServer: public QLocalServer
     IntervalCheck *mIntervalChecker;
     ItemRetrievalThread *mItemRetrievalThread;
     QProcess *mDatabaseProcess;
-    QList< QPointer<AkonadiConnection> > mConnections;
+    QVector< QPointer<AkonadiConnection> > mConnections;
     SearchManager* mSearchManager;
     bool mAlreadyShutdown;
 };
