@@ -62,4 +62,18 @@ class DbInitializerPostgreSql : public DbInitializer
     virtual QString buildCreateRelationTableStatement( const QString &tableName, const RelationDescription &relationDescription ) const;
 };
 
+class DbInitializerVirtuoso : public DbInitializer
+{
+  public:
+    DbInitializerVirtuoso(const QSqlDatabase& database, const QString& templateFile);
+  protected:
+    QString sqlType(const QString& type) const;
+    QString sqlValue(const QString& type, const QString& value) const;
+    bool hasIndex(const QString& tableName, const QString& indexName);
+
+    virtual QString buildCreateTableStatement( const TableDescription &tableDescription ) const;
+    virtual QString buildColumnStatement( const ColumnDescription &columnDescription ) const;
+    virtual QString buildInsertValuesStatement( const TableDescription &tableDescription, const DataDescription &dataDescription ) const;
+};
+
 #endif
